indicatortools.Dynamic
======================

.. abjad-lineage:: abjad.tools.indicatortools.Dynamic.Dynamic

.. autoclass:: abjad.tools.indicatortools.Dynamic.Dynamic

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.Dynamic.Dynamic.composite_dynamic_name_to_steady_state_dynamic_name
      ~abjad.tools.indicatortools.Dynamic.Dynamic.dynamic_name_to_dynamic_ordinal
      ~abjad.tools.indicatortools.Dynamic.Dynamic.dynamic_ordinal_to_dynamic_name
      ~abjad.tools.indicatortools.Dynamic.Dynamic.is_dynamic_name
      ~abjad.tools.indicatortools.Dynamic.Dynamic.name
      ~abjad.tools.indicatortools.Dynamic.Dynamic.__copy__
      ~abjad.tools.indicatortools.Dynamic.Dynamic.__eq__
      ~abjad.tools.indicatortools.Dynamic.Dynamic.__format__
      ~abjad.tools.indicatortools.Dynamic.Dynamic.__hash__
      ~abjad.tools.indicatortools.Dynamic.Dynamic.__ne__
      ~abjad.tools.indicatortools.Dynamic.Dynamic.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.Dynamic.Dynamic.name
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.composite_dynamic_name_to_steady_state_dynamic_name
   :noindex:

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.dynamic_name_to_dynamic_ordinal
   :noindex:

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.dynamic_ordinal_to_dynamic_name
   :noindex:

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.is_dynamic_name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.__hash__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Dynamic.Dynamic.__repr__
   :noindex:
